using System;
using System.ComponentModel;
using DlhSoft.Windows.Data;

namespace GanttChartTaskListViewDatabaseSample
{
    // Define supplemental Task properties and methods to be used in data binding processing.
    partial class Task
    {
        // Return a string representing the task.
        public override string ToString()
        {
            return Content;
        }

        // IsExpanded value is not persisted, and it is initialized to true.
        public bool IsExpanded
        {
            get { return true; }
            set { }
        }

        // Transform EffortHours (decimal renamed from Effort in DataClasses.dbml) to Effort (TimeSpan).
        public TimeSpan Effort
        {
            get { return TimeSpan.FromHours((double)EffortHours); }
            set { EffortHours = (decimal)value.TotalHours; }
        }

        // Transform CompletedEffortHours (decimal renamed from CompletedEffort in DataClasses.dbml) to CompletedEffort (TimeSpan).
        public TimeSpan CompletedEffort
        {
            get { return TimeSpan.FromHours((double)CompletedEffortHours); }
            set { CompletedEffortHours = (decimal)value.TotalHours; }
        }

        // Transform AssignmentsRelation (EntitySet<Assignment> renamed from Assignments in DataClasses.dbml) to Assignments (BindingList<Assignment>) to get automatic collection notifications.
        public BindingList<Assignment> Assignments
        {
            get { return ((IListSource)AssignmentsRelation).GetList() as BindingList<Assignment>; }
        }

        // Transform OriginalPredecessors (EntitySet<Predecessors> renamed from Predecessors in DataClasses.dbml) to Predecessors (BindingList<Predecessor>) to get automatic collection notifications.
        public BindingList<Predecessor> Predecessors
        {
            get { return ((IListSource)PredecessorsRelation).GetList() as BindingList<Predecessor>; }
        }
    }

    // Define supplemental Resource methods to be used in data binding processing.
    partial class Resource
    {
        // Return a string representing the resource.
        public override string ToString()
        {
            return Content;
        }
    }

    // Define supplemental Assignment properties to be used in data binding processing.
    partial class Assignment
    {
        // Transform ResourceRelation (Resource renamed from Resource in DataClasses.dbml) to ResourceItem (object).
        public Resource ResourceItem
        {
            get { return ResourceRelation; }
            set { ResourceRelation = value; }
        }
    }

    // Define supplemental Predecessor properties to be used in data binding processing.
    partial class Predecessor
    {
        // Transform PredecessorTaskRelation (Task renamed from Task1 in DataClasses.dbml) to TaskItem (object).
        public Task TaskItem
        {
            get { return PredecessorTaskRelation; }
            set { PredecessorTaskRelation = value; }
        }

        // Transform DependencyTypeName (string renamed from DependencyType in DataClasses.dbml) to DependencyType (DependencyType).
        public DependencyType DependencyType
        {
            get { return (DependencyType)Enum.Parse(typeof(DependencyType), DependencyTypeName); }
            set { DependencyTypeName = value.ToString(); }
        }

        // Transform LagHours (decimal renamed from Lag in DataClasses.dbml) to Lag (TimeSpan).
        public TimeSpan Lag
        {
            get { return TimeSpan.FromHours((double)LagHours); }
            set { LagHours = (decimal)value.TotalHours; }
        }
    }
}
